Installation
============

Pre-Requisites
--------------

Amoni is built on top of `Docker <https://docker.com>`_ which needs to be installed
on your local machine.

As a minimum, you will need to install the `Docker Engine <https://docs.docker.com/engine/install/>`_
and `Docker Compose <https://docs.docker.com/compose/install/>`_.

If you prefer, you can install the `Docker Desktop App <https://docs.docker.com/desktop/>`_
which also includes the Engine and Docker Compose.

Install Amoni
-------------
The recommended installation method is to use `pipx <https://pypa.github.io/pipx/>`_:

.. code-block:: shell

    pipx install amoni

If you prefer, you can install amoni into any Python environment using:

.. code-block:: shell

   python -m pip install amoni
